@@ -41,7 +41,7 @@ ComicArchiveJob::ComicArchiveJob( const QUrl &dest, Plasma::DataEngine *engine,
     mTotalFiles( -1 ),
     mEngine( engine ),
     mZipFile( new QTemporaryFile ),
-    mZip( 0 ),
+    mZip(nullptr),
     mPluginName( pluginName ),
     mDest( dest )
 {
@@ -73,7 +73,7 @@ bool ComicArchiveJob::isValid() const
     switch ( mType ) {
         case ArchiveFromTo:
             if ( mToIdentifier.isEmpty() || mFromIdentifier.isEmpty() ) {
-                qWarning() << "Not enought data provided to archive a range.";
+                qWarning() << "Not enough data provided to archive a range.";
                 return false;
             }
             break;
@@ -95,14 +95,14 @@ void ComicArchiveJob::setToIdentifier( const QString &toIdentifier )
 {
     mToIdentifier = toIdentifier;
     mToIdentifierSuffix = mToIdentifier;
-    mToIdentifierSuffix.remove( mPluginName + ':' );
+    mToIdentifierSuffix.remove(mPluginName + QLatin1Char(':'));
 }
 
 void ComicArchiveJob::setFromIdentifier( const QString &fromIdentifier )
 {
     mFromIdentifier = fromIdentifier;
     mFromIdentifierSuffix = mFromIdentifier;
-    mFromIdentifierSuffix.remove( mPluginName + ':' );
+    mFromIdentifierSuffix.remove(mPluginName + QLatin1Char(':'));
 }
 
 void ComicArchiveJob::start()
@@ -122,7 +122,7 @@ void ComicArchiveJob::start()
             break;
         }
         case ArchiveFromTo:
-            mDirection = Foward;
+            mDirection = Forward;
             defineTotalNumber();
             requestComic( mFromIdentifier );
             break;
@@ -139,25 +139,25 @@ void ComicArchiveJob::dataUpdated( const QString &source, const Plasma::DataEngi
         return;
     }
 
-    const QString currentIdentifier = data[ "Identifier" ].toString();
+    const QString currentIdentifier = data[QStringLiteral("Identifier")].toString();
     QString currentIdentifierSuffix = currentIdentifier;
-    currentIdentifierSuffix.remove( mPluginName + ':' );
+    currentIdentifierSuffix.remove(mPluginName + QLatin1Char(':'));
 
-    const QImage image = data[ "Image" ].value<QImage>();
-    const bool hasError = data[ "Error" ].toBool() || image.isNull();
-    const QString previousIdentifierSuffix = data[ "Previous identifier suffix" ].toString();
-    const QString nextIdentifierSuffix = data[ "Next identifier suffix" ].toString();
-    const QString firstIdentifierSuffix = data[ "First strip identifier suffix" ].toString();
+    const QImage image = data[QStringLiteral("Image")].value<QImage>();
+    const bool hasError = data[QStringLiteral("Error")].toBool() || image.isNull();
+    const QString previousIdentifierSuffix = data[QStringLiteral("Previous identifier suffix")].toString();
+    const QString nextIdentifierSuffix = data[QStringLiteral("Next identifier suffix")].toString();
+    const QString firstIdentifierSuffix = data[QStringLiteral("First strip identifier suffix")].toString();
 
-    mAuthors << data[ "Comic Author" ].toString().split( ',', QString::SkipEmptyParts );
+    mAuthors << data[QStringLiteral("Comic Author")].toString().split(QLatin1Char(','), QString::SkipEmptyParts);
     mAuthors.removeDuplicates();
 
     if ( mComicTitle.isEmpty() ) {
-        mComicTitle = data[ "Title" ].toString();
+        mComicTitle = data[QStringLiteral("Title")].toString();
     }
 
     if ( hasError ) {
-        qWarning() << "An error occured at" << source << "stopping.";
+        qWarning() << "An error occurred at" << source << "stopping.";
         setErrorText( i18n( "An error happened for identifier %1.", source ) );
         setError( KilledJobError );
         copyZipFileToDestination();
@@ -172,8 +172,8 @@ void ComicArchiveJob::dataUpdated( const QString &source, const Plasma::DataEngi
             if ( mType == ArchiveAll ) {
                 setToIdentifier( currentIdentifier );
             }
-            mDirection = ( firstIdentifierSuffix.isEmpty() ? Backward : Foward );
-            if ( mDirection == Foward ) {
+            mDirection = ( firstIdentifierSuffix.isEmpty() ? Backward : Forward );
+            if ( mDirection == Forward ) {
                 requestComic( suffixToIdentifier( firstIdentifierSuffix ) );
                 return;
             } else {
@@ -182,7 +182,7 @@ void ComicArchiveJob::dataUpdated( const QString &source, const Plasma::DataEngi
                 mToIdentifierSuffix.clear();
             }
         } else if ( mType == ArchiveEndTo ) {
-            mDirection = Foward;
+            mDirection = Forward;
             setToIdentifier( currentIdentifier );
             requestComic( mFromIdentifier );
             return;
@@ -191,7 +191,7 @@ void ComicArchiveJob::dataUpdated( const QString &source, const Plasma::DataEngi
 
     bool worked = false;
     ++mProcessedFiles;
-    if ( mDirection == Foward ) {
+    if ( mDirection == Forward ) {
         QTemporaryFile tempFile;
         worked = tempFile.open();
         worked = worked && tempFile.flush();
@@ -272,8 +272,8 @@ void ComicArchiveJob::defineTotalNumber( const QString &currentSuffix )
     //if there are no strips for certain days/numbers
     if ( !currentSuffix.isEmpty() ) {
         if ( mIdentifierType == Date ) {
-            const QDate current = QDate::fromString( currentSuffix, "yyyy-MM-dd" );
-            const QDate to = QDate::fromString( mToIdentifierSuffix, "yyyy-MM-dd" );
+            const QDate current = QDate::fromString(currentSuffix, QStringLiteral("yyyy-MM-dd"));
+            const QDate to = QDate::fromString(mToIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
             if ( current.isValid() && to.isValid() ) {
                 //processed files + files still to download
                 mTotalFiles = mProcessedFiles + qAbs( current.daysTo( to ) );
@@ -304,8 +304,8 @@ void ComicArchiveJob::findTotalNumberFromTo()
     }
 
     if ( mIdentifierType == Date ) {
-        const QDate from = QDate::fromString( mFromIdentifierSuffix, "yyyy-MM-dd" );
-        const QDate to = QDate::fromString( mToIdentifierSuffix, "yyyy-MM-dd" );
+        const QDate from = QDate::fromString( mFromIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
+        const QDate to = QDate::fromString(mToIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
         if ( from.isValid() && to.isValid() ) {
             mTotalFiles = qAbs( from.daysTo( to ) ) + 1;
         }
@@ -324,7 +324,7 @@ void ComicArchiveJob::findTotalNumberFromTo()
 
 QString ComicArchiveJob::suffixToIdentifier( const QString &suffix ) const
 {
-    return mPluginName + ':' + suffix;
+    return mPluginName + QLatin1Char(':') + suffix;
 }
 
 void ComicArchiveJob::requestComic( QString identifier ) //krazy:exclude=passbyvalue
@@ -336,8 +336,8 @@ void ComicArchiveJob::requestComic( QString identifier ) //krazy:exclude=passbyv
     }
 
     emit description( this, i18n( "Creating Comic Book Archive" ),
-                      qMakePair( QString( "source" ), identifier ),
-                      qMakePair( QString( "destination" ), mDest.toString() ) );
+                      qMakePair(QStringLiteral("source"), identifier),
+                      qMakePair(QStringLiteral("destination"), mDest.toString()));
 
     mEngine->connectSource( identifier, this );
 //    mEngine->query( identifier );
