@@ -23,6 +23,10 @@
 
 #include "potdprovider.h"
 
+#include <QImage>
+
+class KJob;
+
 /**
  * This class provides the image for APOD 
  * "Astronomy Picture Of the Day"
@@ -43,12 +47,12 @@ class ApodProvider : public PotdProvider
          * @param date The date for which the image shall be fetched.
          * @param parent The parent object.
          */
-        ApodProvider( QObject *parent, const QVariantList &args );
+        explicit ApodProvider( QObject *parent, const QVariantList &args );
 
         /**
          * Destroys the APOD provider.
          */
-        ~ApodProvider();
+        ~ApodProvider() override;
 
         /**
          * Returns the requested image.
@@ -56,14 +60,14 @@ class ApodProvider : public PotdProvider
          * Note: This method returns only a valid image after the
          *       finished() signal has been emitted.
          */
-        QImage image() const Q_DECL_OVERRIDE;
+        QImage image() const override;
 
     private:
-      class Private;
-      Private* const d;
+        void pageRequestFinished(KJob *job);
+        void imageRequestFinished(KJob *job);
 
-      Q_PRIVATE_SLOT( d, void pageRequestFinished( KJob* ) )
-      Q_PRIVATE_SLOT( d, void imageRequestFinished( KJob* ) )
+    private:
+        QImage mImage;
 };
 
 #endif
