@@ -21,93 +21,69 @@
 
 #include "natgeoprovider.h"
 
-#include <QtCore/QRegExp>
-#include <QtGui/QImage>
-#include <QRegularExpression>
-
 #include <QDebug>
+
+#include <KPluginFactory>
 #include <KIO/Job>
 
-class NatGeoProvider::Private
+
+NatGeoProvider::NatGeoProvider(QObject *parent, const QVariantList &args)
+    : PotdProvider(parent, args)
 {
-  public:
-    Private( NatGeoProvider *parent )
-      : mParent( parent )
-    {
-    }
+    const QUrl url(QStringLiteral("http://www.nationalgeographic.com/photography/photo-of-the-day/"));
 
-    void pageRequestFinished( KJob* );
-    void imageRequestFinished( KJob* );
+    KIO::StoredTransferJob *job = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
+    connect(job, &KIO::StoredTransferJob::finished, this, &NatGeoProvider::pageRequestFinished);
+}
 
-    NatGeoProvider *mParent;
-    QImage mImage;
+NatGeoProvider::~NatGeoProvider() = default;
 
-    QRegularExpression re;
-};
+QImage NatGeoProvider::image() const
+{
+    return mImage;
+}
 
-void NatGeoProvider::Private::pageRequestFinished( KJob* _job )
+void NatGeoProvider::pageRequestFinished(KJob* _job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>( _job );
     if (job->error()) {
-        emit mParent->error( mParent );
+        emit error(this);
         return;
     }
 
     const QString data = QString::fromUtf8( job->data() );
-    const QStringList lines = data.split('\n');
+    const QStringList lines = data.split(QLatin1Char('\n'));
 
     QString url;
 
-    re.setPattern("^<meta\\s+property=\"og:image\"\\s+content=\"(.*)\".*/>$");
+    re.setPattern(QStringLiteral("^<meta\\s+property=\"og:image\"\\s+content=\"(.*)\".*/>$"));
 
     for (int i = 0; i < lines.size(); i++) {
-        QRegularExpressionMatch match = re.match(lines.at(i).toLocal8Bit().constData());
+        QRegularExpressionMatch match = re.match(lines.at(i));
         if (match.hasMatch()) {
             url = match.captured(1);
         }
     }
 
     if (url.isEmpty()) {
-        emit mParent->error( mParent );
+        emit error(this);
         return;
     }
 
     KIO::StoredTransferJob *imageJob = KIO::storedGet( QUrl(url), KIO::NoReload, KIO::HideProgressInfo );
-    mParent->connect( imageJob, &KIO::StoredTransferJob::finished, mParent, [this] (KJob *job) {
-        imageRequestFinished(job);
-    });
+    connect(imageJob, &KIO::StoredTransferJob::finished, this, &NatGeoProvider::imageRequestFinished);
 }
 
-void NatGeoProvider::Private::imageRequestFinished( KJob *_job )
+void NatGeoProvider::imageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>( _job );
     if ( job->error() ) {
-        emit mParent->error( mParent );
+        emit error(this);
         return;
     }
 
     mImage = QImage::fromData( job->data() );
-    emit mParent->finished( mParent );
-}
-
-NatGeoProvider::NatGeoProvider( QObject *parent, const QVariantList &args )
-    : PotdProvider( parent, args ), d( new Private( this ) )
-{
-    const QUrl url( QLatin1String( "http://www.nationalgeographic.com/photography/photo-of-the-day/" ) );
-    KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::NoReload, KIO::HideProgressInfo );
-    connect( job, &KIO::StoredTransferJob::finished, this, [this] (KJob *job) {
-        d->pageRequestFinished(job);
-    });
-}
-
-NatGeoProvider::~NatGeoProvider()
-{
-    delete d;
-}
-
-QImage NatGeoProvider::image() const
-{
-    return d->mImage;
+    emit finished(this);
 }
 
 K_PLUGIN_FACTORY_WITH_JSON(NatGeoProviderFactory, "natgeoprovider.json", registerPlugin<NatGeoProvider>();)
